@@ -23,4 +23,12 @@ test_that("rules",{
   expect_equal(to_big_camel_case(to_parsed_case(examples)),
                to_big_camel_case(examples)
   ) 
+})
+
+test_that("preserve-names-attribute",{
+  labs <- c(a = "abcDEF", b = "bbccEE", c = "TeESt it")
+  
+  expect_equal(to_big_camel_case(labs),
+              structure(c("AbcDef", "BbccEe", "TeEStIt"), 
+                        .Names = c("a", "b", "c")))
 })
\ No newline at end of file
