@@ -23,4 +23,14 @@ test_that("rules",{
   expect_equal(to_small_camel_case(to_parsed_case(examples)),
                to_small_camel_case(examples)
                )
+})
+
+test_that("preserve-name-attribute",{
+  labs <- c(a = "abcDEF", b = "bbccEE", c = "TeESt it")
+  
+  expect_equal(
+    to_small_camel_case(labs),
+    structure(c("abcDef", "bbccEe", "teEStIt"), .Names = c("a", "b", 
+                                                           "c"))
+  )
 })
\ No newline at end of file
